const api = require('../../utils/api.js')
Page({
  data: {
    style: `--bg:url('${api.baseURL}/public/uploadfile/basics.png')`,
    baseURL: api.baseURL,
    statusBarHeight: 44, // 导航高度
    addressList: [], // 楼栋列表
    unitList: [{
        unitid: '1',
        descr: '一单元'
      },
      {
        unitid: '2',
        descr: '二单元'
      },
      {
        unitid: '3',
        descr: '三单元'
      },
      {
        unitid: '4',
        descr: '四单元'
      },
      {
        unitid: '5',
        descr: '五单元'
      },
      {
        unitid: '',
        descr: '其他'
      }
    ], // 楼栋列表
    addressSelectItem: {}, // 当道选择的楼栋对象
    unitItem: {}, // 单元号
    houseNumber: "", // 门牌号
    oneButton: [],
    showOneButtonDialog: false, //
  },
  // 更新当前选择的单元
  setunitItem(e) {
    this.setData({
      unitItem: this.data.unitList[e.detail.value]
    })
  },
  // 更新门牌号的值
  bindKeyHouseNumber(e) {
    this.setData({
      houseNumber: e.detail.value
    })
  },
  // 更新选择的楼栋
  bindPickerChange(e) {
    this.setData({
      addressSelectItem: this.data.addressList[e.detail.value]
    })
  },

  // 跳转至答题页面
  getUserProfile() {
    // 信息登记完成，跳转至答题录页
    wx.setStorage({
      key: "basicInformation",
      data: {
        "buildingid": this.data.addressSelectItem.buildingid,
        "unit": this.data.unitItem.unitid,
        "room": this.data.houseNumber,
      }
    })
    wx.navigateTo({
      url: '/pages/questionnaire/questionnaire'
    })
  },
  // 分享朋友
  onShareAppMessage: (res) => {
    let data = '';
    wx.getStorage({
      key: 'project',
      success({
        data: {
          surveysheetid = '',
          cid = ''
        }
      }) {
        data = `?surveysheetid=${surveysheetid}&cid=${cid}`
      }
    })
    return {
      title: '业主思维',
      path: '/pages/basicInformation/basicInformation' + data,
      imageUrl: api.baseURL + "/public/uploadfile/logo.png",
      success: (res) => {
        console.log("转发成功", res);
      },
      fail: (res) => {
        console.log("转发失败", res);
      }
    }
  },
  // 分享朋友圈
  onShareTimeline: (res) => {
    let data = '';
    wx.getStorage({
      key: 'project',
      success({
        data: {
          surveysheetid = '',
          cid = ''
        }
      }) {
        data = `?surveysheetid=${surveysheetid}&cid=${cid}`
      }
    })
    return {
      title: '业主思维',
      path: '/pages/basicInformation/basicInformation' + data,
      imageUrl: api.baseURL + "/public/uploadfile/logo.png",
      success: (res) => {
        console.log("转发成功", res);
      },
      fail: (res) => {
        console.log("转发失败", res);
      }
    }
  },
  // 获取楼栋信息
  getBuildings(options) {
    wx.showLoading({
      title: '数据加载中',
    })
    // 获取楼栋信息
    api.get(
      '/api/getbuildings', {
        cid: options.cid
      }
    ).then(({
      data = []
    }) => {
      wx.hideLoading()
      this.setData({
        addressList: data
      })
    }).catch((error) => {
      wx.hideLoading()
    })
  },
  // 校验问卷是否过期
  isFailure(options) {
    api.get('/api/wx_surveysheet/checkbarcode', {
      ...options
    }).then(({
      code,
      data
    }) => {
      if (code === 200 && data == '已过期') {
        wx.reLaunch({
          url: '/pages/pagefailure/pagefailure'
        })
      }
    })
  },
  onLoad(options) {
    const _this = this;
    // 获取设备的信息  
    let systemInfo = wx.getSystemInfoSync();
    // 获取信号区高度, 并设置标题高度
    let statusBarHeight = systemInfo['statusBarHeight'];
    if (systemInfo.platform === 'andorid') {
      statusBarHeight = statusBarHeight + 10;
    } else if (systemInfo.platform === 'ios') {
      statusBarHeight = statusBarHeight + 6;
    } else if (systemInfo.platform === 'devtools') {
      statusBarHeight = statusBarHeight + 9;
    } else {
      statusBarHeight = statusBarHeight;
    }
    _this.setData({
      statusBarHeight
    });
    // 判断是否携带参数
    if (options.cid && options.surveysheetid && options.lenDays) {
      wx.setStorage({
        key: "project",
        data: options,
        success() {
          // 获取用户信息,防止数据不全
          wx.getStorage({
            key: 'userInfo',
            success() {
              _this.isFailure(options);
              _this.getBuildings(options);
            },
            fail() {
              // 如果授权信息丢失，跳转至授权登录页重新授权
              wx.reLaunch({
                url: '/pages/authorization/authorization'
              })
            }
          })
        },
        fail() {
          wx.showToast({
            title: '请重新扫码登录',
            icon: 'error',
            duration: 3000
          })
        }
      })

    } else {
      // 不是扫码登录时，分两种情况处理
      wx.getStorage({
        key: 'project',
        success({
          data
        }) {
          if (data.cid && data.surveysheetid && data.lenDays) {
            // 扫码登录后，临时退出程序，重新进入
            _this.isFailure(data);
            _this.getBuildings(data);
          } else {
            // 非正常登录
            _this.setData({
              showOneButtonDialog: true
            })
          }
        },
        fail() {
          // 非正常登录
          _this.setData({
            showOneButtonDialog: true
          })
        }
      })
    }
  },
  onShow() {
    wx.getStorage({
      key: 'project',
      success({
        data
      }) {
        // 校验问卷是否过期
        api.get('/api/wx_surveysheet/checkbarcode', {
          ...data
        }).then(({
          code,
          data
        }) => {
          if (code === 200 && data == '已过期') {
            wx.reLaunch({
              url: '/pages/pagefailure/pagefailure'
            })
          }
        })
      }
    })
  }
})